@@ -2,9 +2,7 @@
 
 from __future__ import annotations
 
-from datetime import datetime
-
-__all__ = ["datetime_str"]
+from datetime import datetime, timezone
 
 
 def datetime_str() -> str:
@@ -16,4 +14,4 @@ def datetime_str() -> str:
     str
         The current time.
     """
-    return str(datetime.utcnow())
+    return str(datetime.now(tz=timezone.utc))
