@@ -1,8 +1,9 @@
 """Tools for remote file IO using paramiko."""
 
-
 from __future__ import annotations
 
+import errno
+import os
 import shutil
 import stat
 import warnings
@@ -10,13 +11,14 @@ from functools import wraps
 from glob import glob
 from gzip import GzipFile
 from pathlib import Path
-from typing import Any, Callable
+from typing import TYPE_CHECKING, Any, Callable
 
 import paramiko
 from monty.io import zopen
 from paramiko import SFTPClient, SSHClient
 
-__all__ = ["FileClient", "auto_fileclient"]
+if TYPE_CHECKING:
+    from types import TracebackType
 
 
 class FileClient:
@@ -43,13 +45,13 @@ class FileClient:
         self,
         key_filename: str | Path = "~/.ssh/id_rsa",
         config_filename: str | Path = "~/.ssh/config",
-    ):
+    ) -> None:
         self.key_filename = key_filename
         self.config_filename = config_filename
 
         self.connections: dict[str, dict[str, Any]] = {}
 
-    def connect(self, host: str):
+    def connect(self, host: str) -> None:
         """
         Connect to a remote host.
 
@@ -76,8 +78,7 @@ class FileClient:
         self.connections[host] = {"ssh": ssh, "sftp": ssh.open_sftp()}
 
     def get_ssh(self, host: str) -> SSHClient:
-        """
-        Get an SSH connection to a host.
+        """Get an SSH connection to a host.
 
         Parameters
         ----------
@@ -97,8 +98,7 @@ class FileClient:
         return self.connections[host]["ssh"]
 
     def get_sftp(self, host: str) -> SFTPClient:
-        """
-        Get an SFTP connection to a host.
+        """Get an SFTP connection to a host.
 
         Parameters
         ----------
@@ -135,17 +135,15 @@ class FileClient:
         """
         if host is None:
             return Path(path).exists()
-        else:
-            path = str(self.abspath(path, host=host))
-            try:
-                self.get_sftp(host).stat(path)
-                return True
-            except FileNotFoundError:
-                return False
+        path = str(self.abspath(path, host=host))
+        try:
+            self.get_sftp(host).stat(path)
+        except FileNotFoundError:
+            return False
+        return True
 
     def is_file(self, path: str | Path, host: str | None = None) -> bool:
-        """
-        Whether a path is a file.
+        """Whether a path is a file.
 
         Parameters
         ----------
@@ -161,16 +159,14 @@ class FileClient:
         """
         if host is None:
             return Path(path).is_file()
-        else:
-            path = str(self.abspath(path, host=host))
-            try:
-                return stat.S_ISREG(self.get_sftp(host).lstat(path).st_mode)
-            except FileNotFoundError:
-                return False
+        path = str(self.abspath(path, host=host))
+        try:
+            return stat.S_ISREG(self.get_sftp(host).lstat(path).st_mode)
+        except FileNotFoundError:
+            return False
 
     def is_dir(self, path: str | Path, host: str | None = None) -> bool:
-        """
-        Whether a path is a directory.
+        """Whether a path is a directory.
 
         Parameters
         ----------
@@ -186,16 +182,14 @@ class FileClient:
         """
         if host is None:
             return Path(path).is_dir()
-        else:
-            path = str(self.abspath(path, host=host))
-            try:
-                return stat.S_ISDIR(self.get_sftp(host).lstat(path).st_mode)
-            except FileNotFoundError:
-                return False
+        path = str(self.abspath(path, host=host))
+        try:
+            return stat.S_ISDIR(self.get_sftp(host).lstat(path).st_mode)
+        except FileNotFoundError:
+            return False
 
     def listdir(self, path: str | Path, host: str | None = None) -> list[Path]:
-        """
-        Get the directory listing.
+        """Get the directory listing.
 
         Parameters
         ----------
@@ -213,9 +207,8 @@ class FileClient:
             path = self.abspath(path, host=host)
             return [p.relative_to(path) for p in Path(path).iterdir()]
 
-        else:
-            path = str(self.abspath(path, host=host))
-            return [Path(p) for p in self.get_sftp(host).listdir(path)]
+        path = str(self.abspath(path, host=host))
+        return [Path(p) for p in self.get_sftp(host).listdir(path)]
 
     def copy(
         self,
@@ -223,7 +216,7 @@ class FileClient:
         dest_filename: str | Path,
         src_host: str | None = None,
         dest_host: str | None = None,
-    ):
+    ) -> None:
         """
         Copy a file from source to destination.
 
@@ -255,7 +248,7 @@ class FileClient:
             ssh = self.get_ssh(src_host)
             _, _, stderr = ssh.exec_command(f"cp {src_filename} {dest_filename}")
             if len(stderr.readlines()) > 0:
-                warnings.warn(f"Copy command gave error: {stderr}")
+                warnings.warn(f"Copy command gave error: {stderr}", stacklevel=2)
         else:
             # copying between two remote hosts; this is a pain and it is unlikely anyone
             # will want to do it.
@@ -263,7 +256,31 @@ class FileClient:
                 "Copying between two different remote hosts is not supported."
             )
 
-    def remove(self, path: str | Path, host: str | None = None):
+    def link(
+        self,
+        src_filename: str | Path,
+        dest_filename: str | Path,
+    ) -> None:
+        """
+        Link a file from source to destination.
+
+        Parameters
+        ----------
+        src_filename : str or Path
+            Full path to source file.
+        dest_filename : str or Path
+            Full path to destination file.
+        """
+        try:
+            os.symlink(src_filename, dest_filename)
+        except OSError as exc:
+            if exc.errno == errno.EEXIST:
+                os.remove(dest_filename)
+                os.symlink(src_filename, dest_filename)
+            else:
+                raise
+
+    def remove(self, path: str | Path, host: str | None = None) -> None:
         """
         Remove a file (does not work on directories).
 
@@ -285,7 +302,7 @@ class FileClient:
         old_path: str | Path,
         new_path: str | Path,
         host: str | None = None,
-    ):
+    ) -> None:
         """
         Rename (move) a file.
 
@@ -306,8 +323,7 @@ class FileClient:
             self.get_sftp(host).rename(old_path, new_path)
 
     def abspath(self, path: str | Path, host: str | None = None) -> Path:
-        """
-        Get the absolute path.
+        """Get the absolute path.
 
         Parameters
         ----------
@@ -323,10 +339,9 @@ class FileClient:
         """
         if host is None:
             return Path(path).absolute()
-        else:
-            ssh = self.get_ssh(host)
-            _, stdout, _ = ssh.exec_command(f"readlink -f {path}")
-            return Path([o.split("\n")[0] for o in stdout][0])
+        ssh = self.get_ssh(host)
+        _, stdout, _ = ssh.exec_command(f"readlink -f {path}")
+        return Path(next(o.split("\n")[0] for o in stdout))
 
     def glob(self, path: str | Path, host: str | None = None) -> list[Path]:
         """
@@ -358,8 +373,8 @@ class FileClient:
         path: str | Path,
         host: str | None = None,
         compresslevel: int = 6,
-        force: bool = False,
-    ):
+        force: bool | str = False,
+    ) -> None:
         """
         Gzip a file.
 
@@ -372,39 +387,58 @@ class FileClient:
         compresslevel : bool
             Level of compression, 1-9. 9 is default for GzipFile, 6 is default for gzip.
         force : bool
-            Overwrite gzipped file if it already exists.
+            How to handle writing a gzipped file if it already exists. Accepts
+            either a string or bool:
+
+            - `"force"` or `True`: Overwrite gzipped file if it already exists.
+            - `"raise"` or `False`: Raise an error if file already exists.
+            - `"skip"` Skip file if it already exists.
         """
         path = self.abspath(path, host=host)
         path_gz = path.parent / f"{path.name}.gz"
 
         if str(path).lower().endswith("gz"):
-            warnings.warn(f"{path} is already gzipped, skipping...")
-            return None
+            warnings.warn(f"{path} is already gzipped, skipping...", stacklevel=1)
+            return
 
         if self.is_dir(path, host=host):
-            warnings.warn(f"{path} is a directory, skipping...")
-            return None
+            warnings.warn(f"{path} is a directory, skipping...", stacklevel=1)
+            return
 
-        if self.exists(path_gz, host=host) and not force:
-            raise FileExistsError(f"{path_gz} file already exists.")
+        if self.exists(path_gz, host=host):
+            if force is False or force == "raise":
+                raise FileExistsError(f"{path_gz} file already exists")
+            if force is True or force == "force":
+                pass
+            elif force == "skip":
+                warnings.warn(
+                    f"{path_gz} file already exists, skipping...", stacklevel=2
+                )
+                return
+            else:
+                raise ValueError(
+                    f"Invalid value for force: {force} "
+                    "(must be True, False, 'raise', 'force', or 'skip'))"
+                )
 
         if host is None:
-            with open(path, "rb") as f_in, GzipFile(
-                path_gz, "wb", compresslevel=compresslevel
-            ) as f_out:
+            with (
+                open(path, "rb") as f_in,
+                GzipFile(path_gz, "wb", compresslevel=compresslevel) as f_out,
+            ):
                 shutil.copyfileobj(f_in, f_out)
             shutil.copystat(path, path_gz)
             path.unlink()
         else:
             ssh = self.get_ssh(host)
-            _, stdout, _ = ssh.exec_command(f"gzip -f {str(path)}")
+            _, _stdout, _ = ssh.exec_command(f"gzip -f {path!s}")
 
     def gunzip(
         self,
         path: str | Path,
         host: str | None = None,
-        force: bool = False,
-    ):
+        force: bool | str = False,
+    ) -> None:
         """
         Ungzip a file.
 
@@ -415,17 +449,35 @@ class FileClient:
         host : str or None
             A remote file system host on which to perform file operations.
         force : bool
-            Overwrite non-gzipped file if it already exists.
+            How to handle writing a non-gzipped file if it already exists. Accepts
+            either a string or bool:
+
+            - `"force"` or `True`: Overwrite non-gzipped file if it already exists.
+            - `"raise"` or `False`: Raise an error if file already exists.
+            - `"skip"` Skip file if it already exists.
         """
         path = self.abspath(path, host=host)
         path_nongz = path.with_suffix("")
 
         if not str(path).lower().endswith("gz"):
-            warnings.warn(f"{path} is not gzipped, skipping...")
-            return None
+            warnings.warn(f"{path} is not gzipped, skipping...", stacklevel=2)
+            return
 
-        if self.exists(path_nongz, host=host) and not force:
-            raise FileExistsError(f"{path_nongz} file already exists")
+        if self.exists(path_nongz, host=host):
+            if force is False or force == "raise":
+                raise FileExistsError(f"{path_nongz} file already exists")
+            if force is True or force == "force":
+                pass
+            elif force == "skip":
+                warnings.warn(
+                    f"{path_nongz} file already exists, skipping...", stacklevel=2
+                )
+                return
+            else:
+                raise ValueError(
+                    f"Invalid value for force: {force} "
+                    "(must be True, False, 'raise', 'force', or 'skip'))"
+                )
 
         if host is None:
             with open(path_nongz, "wb") as f_out, zopen(path, "rb") as f_in:
@@ -433,20 +485,25 @@ class FileClient:
             path.unlink()
         else:
             ssh = self.get_ssh(host)
-            _, stdout, _ = ssh.exec_command(f"gunzip -f {str(path)}")
+            _stdin, _stdout, _stderr = ssh.exec_command(f"gunzip -f {path!s}")
 
-    def close(self):
+    def close(self) -> None:
         """Close all connections."""
         for connection in self.connections.values():
             connection["ssh"].close()
             connection["sftp"].close()
         self.connections = {}
 
-    def __enter__(self):
+    def __enter__(self) -> FileClient:  # noqa: PYI034
         """Support for "with" context."""
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_val: BaseException | None,
+        exc_tb: TracebackType | None,
+    ) -> None:
         """Support for "with" context."""
         self.close()
 
@@ -489,9 +546,9 @@ def get_ssh_connection(
         ssh_config = paramiko.SSHConfig().from_path(str(config_filename))
 
         host_config = ssh_config.lookup(hostname)  # type: ignore[attr-defined]
-        for k in ("hostname", "user", "port"):
-            if k in host_config:
-                config[k.replace("user", "username")] = host_config[k]
+        for key in ("hostname", "user", "port"):
+            if key in host_config:
+                config[key.replace("user", "username")] = host_config[key]
 
         if "proxycommand" in host_config:
             config["sock"] = paramiko.ProxyCommand(host_config["proxycommand"])
@@ -502,7 +559,7 @@ def get_ssh_connection(
     return client
 
 
-def auto_fileclient(method: Callable | None = None):
+def auto_fileclient(method: Callable | None = None) -> Callable:
     """
     Automatically pass a FileClient to the function if not already present in kwargs.
 
@@ -518,10 +575,10 @@ def auto_fileclient(method: Callable | None = None):
         by the decorator.
     """
 
-    def decorator(func):
+    def decorator(func: Callable) -> Callable:
         @wraps(func)
-        def gen_fileclient(*args, **kwargs):
-            file_client = kwargs.get("file_client", None)
+        def gen_file_client(*args, **kwargs) -> Any:
+            file_client = kwargs.get("file_client")
             if file_client is None:
                 with FileClient() as file_client:
                     kwargs["file_client"] = file_client
@@ -529,7 +586,7 @@ def auto_fileclient(method: Callable | None = None):
             else:
                 return func(*args, **kwargs)
 
-        return gen_fileclient
+        return gen_file_client
 
     # See if we're being called as @auto_fileclient or @auto_fileclient().
     if method is None:
