@@ -3,16 +3,21 @@
 from __future__ import annotations
 
 from itertools import chain
+from typing import TYPE_CHECKING
 
 import numpy as np
 from maggma.builders import Builder
-from maggma.core import Store
 from pydash import get
 from pymatgen.analysis.elasticity import Deformation, Stress
 
 from atomate2 import SETTINGS
 from atomate2.common.schemas.elastic import ElasticDocument
 
+if TYPE_CHECKING:
+    from collections.abc import Generator
+
+    from maggma.core import Store
+
 
 class ElasticBuilder(Builder):
     """
@@ -55,11 +60,10 @@ class ElasticBuilder(Builder):
         fitting_method: str = SETTINGS.ELASTIC_FITTING_METHOD,
         structure_match_tol: float = 1e-5,
         **kwargs,
-    ):
-
+    ) -> None:
         self.tasks = tasks
         self.elasticity = elasticity
-        self.query = query if query else {}
+        self.query = query or {}
         self.kwargs = kwargs
         self.symprec = symprec
         self.fitting_method = fitting_method
@@ -67,16 +71,15 @@ class ElasticBuilder(Builder):
 
         super().__init__(sources=[tasks], targets=[elasticity], **kwargs)
 
-    def ensure_indexes(self):
+    def ensure_indexes(self) -> None:
         """Ensure indices on the tasks and elasticity collections."""
         self.tasks.ensure_index("output.formula_pretty")
         self.tasks.ensure_index("last_updated")
         self.elasticity.ensure_index("fitting_data.uuids.0")
         self.elasticity.ensure_index("last_updated")
 
-    def get_items(self):
-        """
-        Get all items to process into elastic documents.
+    def get_items(self) -> Generator:
+        """Get all items to process into elastic documents.
 
         Yields
         ------
@@ -88,16 +91,12 @@ class ElasticBuilder(Builder):
         self.logger.debug("Adding indices")
         self.ensure_indexes()
 
-        q = dict(self.query)
-
         # query for deformations
-        q.update(
-            {
-                "output.transformations.history.0.@class": "DeformationTransformation",
-                "output.orig_inputs.NSW": {"$gt": 1},
-                "output.orig_inputs.ISIF": {"$gt": 2},
-            }
-        )
+        qry = dict(self.query) | {
+            "output.transformations.history.0.@class": "DeformationTransformation",
+            "output.orig_inputs.NSW": {"$gt": 1},
+            "output.orig_inputs.ISIF": {"$gt": 2},
+        }
         return_props = [
             "uuid",
             "output.transformations",
@@ -107,16 +106,15 @@ class ElasticBuilder(Builder):
         ]
 
         self.logger.info("Starting aggregation")
-        nformulas = len(self.tasks.distinct("output.formula_pretty", criteria=q))
+        n_formulas = len(self.tasks.distinct("output.formula_pretty", criteria=qry))
         results = self.tasks.groupby(
-            "output.formula_pretty", criteria=q, properties=return_props
+            "output.formula_pretty", criteria=qry, properties=return_props
         )
         self.logger.info("Aggregation complete")
 
-        for n, (keys, docs) in enumerate(results):
-            self.logger.debug(
-                f"Getting {keys['output']['formula_pretty']} ({n + 1} of {nformulas})"
-            )
+        for idx, (keys, docs) in enumerate(results):
+            formula = keys["output"]["formula_pretty"]
+            self.logger.debug(f"Getting {formula} ({idx + 1} of {n_formulas})")
             yield docs
 
     def process_item(self, tasks: list[dict]) -> list[ElasticDocument]:
@@ -145,15 +143,15 @@ class ElasticBuilder(Builder):
         grouped = _group_deformations(tasks, self.structure_match_tol)
 
         elastic_docs = []
-        for tasks in grouped:
+        for group in grouped:
             elastic_doc = _get_elastic_document(
-                tasks, self.symprec, self.fitting_method
+                group, self.symprec, self.fitting_method
             )
             elastic_docs.append(elastic_doc)
 
         return elastic_docs
 
-    def update_targets(self, items: list[ElasticDocument]):
+    def update_targets(self, items: list[ElasticDocument]) -> None:
         """
         Insert new elastic documents into the elasticity store.
 
@@ -162,11 +160,11 @@ class ElasticBuilder(Builder):
         items : list of .ElasticDocument
             A list of elasticity documents.
         """
-        items = chain.from_iterable(filter(bool, items))  # type: ignore
+        _items = chain.from_iterable(filter(bool, items))
 
-        if len(items) > 0:
-            self.logger.info(f"Updating {len(items)} elastic documents")
-            self.elasticity.update(items, key="fitting_data.uuids.0")
+        if len(list(_items)) > 0:
+            self.logger.info(f"Updating {len(list(_items))} elastic documents")
+            self.elasticity.update(_items, key="fitting_data.uuids.0")
         else:
             self.logger.info("No items to update")
 
