@@ -5,17 +5,19 @@ from __future__ import annotations
 import logging
 import re
 from pathlib import Path
-from typing import Sequence
-
-from pymatgen.core import Structure
+from typing import TYPE_CHECKING
 
 from atomate2 import SETTINGS
 from atomate2.common.files import copy_files, get_zfile, gunzip_files, rename_files
 from atomate2.utils.file_client import FileClient, auto_fileclient
 from atomate2.utils.path import strip_hostname
-from atomate2.vasp.sets.base import VaspInputGenerator
 
-__all__ = ["copy_vasp_outputs", "get_largest_relax_extension"]
+if TYPE_CHECKING:
+    from collections.abc import Sequence
+
+    from pymatgen.core import Structure
+
+    from atomate2.vasp.sets.base import VaspInputGenerator
 
 
 logger = logging.getLogger(__name__)
@@ -25,16 +27,17 @@ logger = logging.getLogger(__name__)
 def copy_vasp_outputs(
     src_dir: Path | str,
     src_host: str | None = None,
-    additional_vasp_files: Sequence[str] = tuple(),
+    additional_vasp_files: Sequence[str] = (),
     contcar_to_poscar: bool = True,
+    force_overwrite: bool | str = False,
     file_client: FileClient | None = None,
-):
+) -> None:
     """
     Copy VASP output files to the current directory.
 
     For folders containing multiple calculations (e.g., suffixed with relax1, relax2,
     etc), this function will only copy the files with the highest numbered suffix and
-    the suffix will be removed. Additional vasp files will be also be  copied with the
+    the suffix will be removed. Additional vasp files will be also be copied with the
     same suffix applied. Lastly, this function will gunzip any gzipped files.
 
     Parameters
@@ -50,6 +53,13 @@ def copy_vasp_outputs(
         Additional files to copy, e.g. ["CHGCAR", "WAVECAR"].
     contcar_to_poscar : bool
         Move CONTCAR to POSCAR (original POSCAR is not copied).
+    force_overwrite : bool or str
+        How to handle overwriting existing files during the copy step. Accepts
+        either a string or bool:
+
+            - `"force"` or `True`: Overwrite existing files if they already exist.
+            - `"raise"` or `False`: Raise an error if files already exist.
+            - `"skip"` Skip files they already exist.
     file_client : .FileClient
         A file client to use for performing file operations.
     """
@@ -67,14 +77,14 @@ def copy_vasp_outputs(
     # find optional files; do not fail if KPOINTS is missing, this might be KSPACING
     # note: POTCAR files never have the relax extension, whereas KPOINTS files should
     optional_files = []
-    for file in ["POTCAR", "POTCAR.spec", "KPOINTS" + relax_ext]:
+    for file in ("POTCAR", "POTCAR.spec", "KPOINTS" + relax_ext):
         found_file = get_zfile(directory_listing, file, allow_missing=True)
         if found_file is not None:
             optional_files.append(found_file)
 
     # check at least one type of POTCAR file is included
     if len([f for f in optional_files if "POTCAR" in f.name]) == 0:
-        raise FileNotFoundError("Could not find POTCAR file to copy.")
+        raise FileNotFoundError(f"Could not find a POTCAR file in {src_dir!r} to copy")
 
     copy_files(
         src_dir,
@@ -87,14 +97,17 @@ def copy_vasp_outputs(
         include_files=required_files + optional_files,
         allow_missing=True,
         file_client=file_client,
+        force=force_overwrite,
     )
 
     # rename files to remove relax extension
     if relax_ext:
         all_files = optional_files + required_files
         files_to_rename = {
-            k.name.replace(".gz", ""): k.name.replace(relax_ext, "").replace(".gz", "")
-            for k in all_files
+            file.name.replace(".gz", ""): file.name.replace(relax_ext, "").replace(
+                ".gz", ""
+            )
+            for file in all_files
         }
         rename_files(files_to_rename, allow_missing=True, file_client=file_client)
 
@@ -137,7 +150,7 @@ def get_largest_relax_extension(
         return ""
 
     numbers = [re.search(r".relax(\d+)", file.name).group(1) for file in relax_files]
-    max_relax = max(numbers, key=lambda x: int(x))
+    max_relax = max(numbers, key=int)
     return f".relax{max_relax}"
 
 
@@ -150,7 +163,7 @@ def write_vasp_input_set(
     potcar_spec: bool = False,
     clean_prev: bool = True,
     **kwargs,
-):
+) -> None:
     """
     Write VASP input set.
 
@@ -188,4 +201,4 @@ def write_vasp_input_set(
                 Path(filename).unlink()
 
     logger.info("Writing VASP input set.")
-    vis.write_input(directory, potcar_spec=potcar_spec, **kwargs)
+    vis.write_input(directory, **kwargs)
