@@ -4,11 +4,10 @@ from __future__ import annotations
 
 from copy import deepcopy
 from dataclasses import dataclass, field
-from pathlib import Path
+from typing import TYPE_CHECKING
 
 import numpy as np
 from jobflow import Flow, Maker, job
-from pymatgen.core.structure import Structure
 
 from atomate2 import SETTINGS
 from atomate2.amset.jobs import AmsetMaker
@@ -24,7 +23,6 @@ from atomate2.vasp.jobs.amset import (
     generate_wavefunction_coefficients,
     run_amset_deformations,
 )
-from atomate2.vasp.jobs.base import BaseVaspMaker
 from atomate2.vasp.jobs.core import (
     DielectricMaker,
     HSEBSMaker,
@@ -35,7 +33,13 @@ from atomate2.vasp.jobs.core import (
 )
 from atomate2.vasp.sets.core import HSEBSSetGenerator
 
-__all__ = ["VaspAmsetMaker", "DeformationPotentialMaker", "HSEVaspAmsetMaker"]
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from pymatgen.core.structure import Structure
+
+    from atomate2.vasp.jobs.base import BaseVaspMaker
+
 
 _DEFAULT_DOPING = (
     1e16,
@@ -82,26 +86,23 @@ class DeformationPotentialMaker(Maker):
     def make(
         self,
         structure: Structure,
-        prev_vasp_dir: str | Path | None = None,
+        prev_dir: str | Path | None = None,
         ibands: tuple[list[int], list[int]] = None,
-    ):
-        """
-        Make flow to calculate acoustic deformation potentials.
+    ) -> Flow:
+        """Make flow to calculate acoustic deformation potentials.
 
         Parameters
         ----------
         structure : .Structure
             A pymatgen structure.
-        prev_vasp_dir : str or Path or None
+        prev_dir : str or Path or None
             A previous vasp calculation directory to use for copying outputs.
         ibands : tuple of list of int
             Which bands to include in the deformation.h5 file. Given as a tuple of one
             or two lists (one for each spin channel). The bands indices are zero
             indexed.
         """
-        bulk = self.static_deformation_maker.make(
-            structure, prev_vasp_dir=prev_vasp_dir
-        )
+        bulk = self.static_deformation_maker.make(structure, prev_dir=prev_dir)
         bulk.append_name("bulk ", prepend=True)
 
         # all deformation calculations need to be on the same k-point mesh, to achieve
@@ -114,7 +115,7 @@ class DeformationPotentialMaker(Maker):
         vasp_deformation_calcs = run_amset_deformations(
             bulk.output.structure,
             symprec=self.symprec,
-            prev_vasp_dir=bulk.output.dir_name,
+            prev_dir=bulk.output.dir_name,
             static_deformation_maker=self.static_deformation_maker,
         )
 
@@ -152,7 +153,7 @@ class VaspAmsetMaker(Maker):
     temperatures : tuple of float
         Temperatures at which to calculate transport properties.
     use_hse_gap : bool
-        Whether to perform a HSE06 calculation to calculate the band gap for use in
+        Whether to perform an HSE06 calculation to calculate the band gap for use in
         AMSET. This can impact the results for small band gap materials.
     relax_maker : .BaseVaspMaker
         A maker to perform a tight relaxation on the bulk. Set to ``None`` to skip the
@@ -201,44 +202,43 @@ class VaspAmsetMaker(Maker):
     def make(
         self,
         structure: Structure,
-        prev_vasp_dir: str | Path | None = None,
-    ):
-        """
-        Make flow to calculate electronic transport properties using AMSET and VASP.
+        prev_dir: str | Path | None = None,
+    ) -> Flow:
+        """Make flow to calculate electronic transport properties using AMSET and VASP.
 
         Parameters
         ----------
         structure : .Structure
             A pymatgen structure.
-        prev_vasp_dir : str or Path or None
+        prev_dir : str or Path or None
             A previous vasp calculation directory to use for copying outputs.
         """
         jobs = []
 
         if self.relax_maker is not None:
             # optionally relax the structure
-            bulk = self.relax_maker.make(structure, prev_vasp_dir=prev_vasp_dir)
+            bulk = self.relax_maker.make(structure, prev_dir=prev_dir)
             jobs.append(bulk)
             structure = bulk.output.structure
-            prev_vasp_dir = bulk.output.dir_name
+            prev_dir = bulk.output.dir_name
 
-        static = self.static_maker.make(structure, prev_vasp_dir=prev_vasp_dir)
+        static = self.static_maker.make(structure, prev_dir=prev_dir)
 
         # dense band structure for eigenvalues and wave functions
         dense_bs = self.dense_uniform_maker.make(
-            static.output.structure, prev_vasp_dir=static.output.dir_name
+            static.output.structure, prev_dir=static.output.dir_name
         )
 
         # elastic constant
         elastic = self.elastic_maker.make(
             static.output.structure,
-            prev_vasp_dir=static.output.dir_name,
+            prev_dir=static.output.dir_name,
             equilibrium_stress=static.output.output.stress,
         )
 
         # dielectric constant
         dielectric = self.dielectric_maker.make(
-            static.output.structure, prev_vasp_dir=static.output.dir_name
+            static.output.structure, prev_dir=static.output.dir_name
         )
 
         # polar phonon frequency
@@ -255,7 +255,7 @@ class VaspAmsetMaker(Maker):
         # deformation potentials
         deformation = self.deformation_potential_maker.make(
             static.output.structure,
-            prev_vasp_dir=static.output.dir_name,
+            prev_dir=static.output.dir_name,
             ibands=wavefunction.output["ibands"],
         )
 
@@ -299,7 +299,7 @@ class VaspAmsetMaker(Maker):
         if self.use_hse_gap and "bandgap" not in self.amset_settings:
             gap = self.hse_gap_maker.make(
                 dense_bs.output.structure,
-                prev_vasp_dir=dense_bs.output.dir_name,
+                prev_dir=dense_bs.output.dir_name,
                 mode="gap",
             )
             settings["bandgap"] = gap.output.output.bandgap
@@ -383,44 +383,43 @@ class HSEVaspAmsetMaker(Maker):
     def make(
         self,
         structure: Structure,
-        prev_vasp_dir: str | Path | None = None,
-    ):
-        """
-        Make flow to calculate electronic transport properties using AMSET and VASP.
+        prev_dir: str | Path | None = None,
+    ) -> Flow:
+        """Make flow to calculate electronic transport properties using AMSET and VASP.
 
         Parameters
         ----------
         structure : Structure
             A pymatgen structure.
-        prev_vasp_dir : str or Path or None
+        prev_dir : str or Path or None
             A previous vasp calculation directory to use for copying outputs.
         """
         jobs = []
 
         if self.relax_maker is not None:
             # optionally relax the structure
-            bulk = self.relax_maker.make(structure, prev_vasp_dir=prev_vasp_dir)
+            bulk = self.relax_maker.make(structure, prev_dir=prev_dir)
             jobs.append(bulk)
             structure = bulk.output.structure
-            prev_vasp_dir = bulk.output.dir_name
+            prev_dir = bulk.output.dir_name
 
-        static = self.static_maker.make(structure, prev_vasp_dir=prev_vasp_dir)
+        static = self.static_maker.make(structure, prev_dir=prev_dir)
 
         # dense band structure for eigenvalues and wave functions
         dense_bs = self.dense_uniform_maker.make(
-            static.output.structure, prev_vasp_dir=static.output.dir_name
+            static.output.structure, prev_dir=static.output.dir_name
         )
 
         # elastic constant
         elastic = self.elastic_maker.make(
             static.output.structure,
-            prev_vasp_dir=static.output.dir_name,
+            prev_dir=static.output.dir_name,
             equilibrium_stress=static.output.output.stress,
         )
 
         # dielectric constant
         dielectric = self.dielectric_maker.make(
-            static.output.structure, prev_vasp_dir=static.output.dir_name
+            static.output.structure, prev_dir=static.output.dir_name
         )
 
         # polar phonon frequency
@@ -437,7 +436,7 @@ class HSEVaspAmsetMaker(Maker):
         # deformation potentials
         deformation = self.deformation_potential_maker.make(
             static.output.structure,
-            prev_vasp_dir=static.output.dir_name,
+            prev_dir=static.output.dir_name,
             ibands=wavefunction.output["ibands"],
         )
 
