@@ -4,19 +4,14 @@ from __future__ import annotations
 
 import logging
 from dataclasses import dataclass, field
-from pathlib import Path
+from typing import TYPE_CHECKING
 
+from emmet.core.tasks import TaskDoc
 from jobflow import Flow, Maker, OutputReference
 from jobflow.core.maker import recursive_call
-from pymatgen.core.structure import Structure
-from pymatgen.io.vasp.outputs import Vasprun
 
-from atomate2.common.files import get_zfile
 from atomate2.common.flows import defect as defect_flows
-from atomate2.common.schemas.defects import CCDDocument
-from atomate2.utils.file_client import FileClient
 from atomate2.vasp.flows.core import DoubleRelaxMaker
-from atomate2.vasp.jobs.base import BaseVaspMaker
 from atomate2.vasp.jobs.core import RelaxMaker, StaticMaker
 from atomate2.vasp.jobs.defect import calculate_finite_diff
 from atomate2.vasp.sets.defect import (
@@ -26,6 +21,13 @@ from atomate2.vasp.sets.defect import (
     HSEChargeStateRelaxSetGenerator,
 )
 
+if TYPE_CHECKING:
+    from pymatgen.core.structure import Structure
+    from pymatgen.entries.computed_entries import ComputedStructureEntry
+
+    from atomate2.common.schemas.defects import CCDDocument
+    from atomate2.vasp.jobs.base import BaseVaspMaker
+
 logger = logging.getLogger(__name__)
 
 
@@ -58,9 +60,7 @@ HSE_DOUBLE_RELAX = DoubleRelaxMaker(
             user_kpoints_settings=SPECIAL_KPOINT
         ),
         task_document_kwargs={"store_volumetric_data": ["locpot"]},
-        copy_vasp_kwargs={
-            "additional_vasp_files": ("WAVECAR",),
-        },
+        copy_vasp_kwargs={"additional_vasp_files": ("WAVECAR",)},
     ),
 )
 GRID_KEYS = ["NGX", "NGY", "NGZ", "NGXF", "NGYF", "NGZF"]
@@ -74,10 +74,11 @@ class FormationEnergyMaker(defect_flows.FormationEnergyMaker):
     this maker is the `relax_maker` which contains the settings for the atomic
     relaxations that each defect supercell will undergo. The `relax_maker`
     uses a `ChargeStateRelaxSetGenerator` by default but more complex makers
-    like the `HSE_DOUBLE_RELAX` can be used for more accurate (but expensive)
+    like the ``HSE_DOUBLE_RELAX`` can be used for more accurate (but expensive)
     calculations.
-    If the `validate_maker` is set to True, the maker will check for some basic
-    settings in the `relax_maker` to make sure the calculations are done correctly.
+
+    If the ``validate_maker`` is set to True, the maker will check for some basic
+    settings in the ``relax_maker`` to make sure the calculations are done correctly.
 
     Attributes
     ----------
@@ -85,10 +86,11 @@ class FormationEnergyMaker(defect_flows.FormationEnergyMaker):
         A maker to perform a atomic-position-only relaxation on the defect charge
         states. Since these calculations are expensive and the settings might get
         messy, it is recommended for each implementation of this maker to check
-        some of the most important settings in the `relax_maker`.  Please see
-        `FormationEnergyMaker.validate_maker` for more details.
+        some of the most important settings in the `relax_maker`. Please see
+        ``FormationEnergyMaker.validate_maker`` for more details.
+
     bulk_relax_maker: Maker
-        If None, the same `defect_relax_maker` will be used for the bulk supercell.
+        If None, the same ``defect_relax_maker`` will be used for the bulk supercell.
         A maker to used to perform the bulk supercell calculation. For marginally
         converged calculations, it might be desirable to perform an additional
         lattice relaxation on the bulk supercell to make sure the energies are more
@@ -99,13 +101,66 @@ class FormationEnergyMaker(defect_flows.FormationEnergyMaker):
         lattice relaxation, you should manually set the grid size.
 
         .. code-block:: python
+
             relax_set = MPRelaxSet(defect.get_supercell_structure())
             ng, ngf = relax_set.calculate_ng()
             params = ["NGX", "NGY", "NGZ", "NGXF", "NGYF", "NGZF"]
             ng_settings = dict(zip(params, ng + ngf))
             relax_maker = update_user_incar_settings(relax_maker, ng_settings)
+
     name: str
         The name of the flow created by this maker.
+
+    relax_radius:
+        The radius to include around the defect site for the relaxation.
+        If "auto", the radius will be set to the maximum that will fit inside
+        a periodic cell. If None, all atoms will be relaxed.
+
+    perturb:
+        The amount to perturb the sites in the supercell. Only perturb the
+        sites with selective dynamics set to True. So this setting only works
+        with `relax_radius`.
+
+    collect_defect_entry_data: bool
+        Whether to collect the defect entry data at the end of the flow.
+        If True, the output of all the charge states for each symmetry distinct
+        defect will be collected into a list of dictionaries that can be used
+        to create a DefectEntry. The data here can be trivially combined with
+        phase diagram data from the materials project API to create the formation
+        energy diagrams.
+
+        .. note::
+
+            Once we remove the requirement for explicit bulk supercell
+            calculations, this setting will be removed. It is only needed because
+            the bulk supercell locpot is currently needed for the finite-size
+            correction calculation.
+
+        Output format for the DefectEntry data:
+
+        .. code-block:: python
+
+            [
+                {
+                    "bulk_dir_name": "computer1:/folder1",
+                    "bulk_locpot": {...},
+                    "bulk_uuid": "48fb6da7-dc2b-4dcb-b1c8-1203c0f72ce3",
+                    "defect_dir_name": "computer1:/folder2",
+                    "defect_entry": {...},
+                    "defect_locpot": {...},
+                    "defect_uuid": "e9af2725-d63c-49b8-a01f-391540211750",
+                },
+                {
+                    "bulk_dir_name": "computer1:/folder3",
+                    "bulk_locpot": {...},
+                    "bulk_uuid": "48fb6da7-dc2b-4dcb-b1c8-1203c0f72ce3",
+                    "defect_dir_name": "computer1:/folder4",
+                    "defect_entry": {...},
+                    "defect_locpot": {...},
+                    "defect_uuid": "a1c31095-0494-4eed-9862-95311f80a993",
+                },
+            ]
+
     """
 
     defect_relax_maker: BaseVaspMaker = field(
@@ -119,7 +174,9 @@ class FormationEnergyMaker(defect_flows.FormationEnergyMaker):
     bulk_relax_maker: BaseVaspMaker | None = None
     name: str = "formation energy"
 
-    def structure_from_prv(self, previous_dir: str):
+    def sc_entry_and_locpot_from_prv(
+        self, previous_dir: str
+    ) -> tuple[ComputedStructureEntry, dict]:
         """Copy the output structure from previous directory.
 
         Read the vasprun.xml file from the previous directory
@@ -132,15 +189,16 @@ class FormationEnergyMaker(defect_flows.FormationEnergyMaker):
 
         Returns
         -------
-        structure: Structure
+        ComputedStructureEntry
         """
-        fc = FileClient()
-        files = fc.listdir(previous_dir)
-        vasprun_file = Path(previous_dir) / get_zfile(files, "vasprun.xml")
-        vasprun = Vasprun(vasprun_file)
-        return vasprun.final_structure
+        task_doc = TaskDoc.from_directory(previous_dir)
+        return task_doc.structure_entry, task_doc.calcs_reversed[0].output.locpot
 
-    def validate_maker(self):
+    def get_planar_locpot(self, task_doc: TaskDoc) -> dict:
+        """Get the planar-averaged electrostatic potential."""
+        return task_doc.calcs_reversed[0].output.locpot
+
+    def validate_maker(self) -> None:
         """Check some key settings in the relax maker.
 
         Since this workflow is pretty complex but allows you to use any
@@ -152,12 +210,12 @@ class FormationEnergyMaker(defect_flows.FormationEnergyMaker):
             `ISIF = 2` and `use_structure_charge = True`
         """
 
-        def check_defect_relax_maker(relax_maker: RelaxMaker):
+        def check_defect_relax_maker(relax_maker: RelaxMaker) -> RelaxMaker:
             input_gen = relax_maker.input_set_generator
             if input_gen.use_structure_charge is False:
                 raise ValueError("use_structure_charge should be set to True")
-            isif_ = input_gen.get_incar_updates(None).get("ISIF", None)
-            isif = input_gen.user_incar_settings.get("ISIF", isif_)
+            default_isif = input_gen.incar_updates.get("ISIF")
+            isif = input_gen.user_incar_settings.get("ISIF", default_isif)
             if isif != 2:
                 raise ValueError("ISIF should be set to 2")
             return relax_maker
@@ -197,7 +255,7 @@ class ConfigurationCoordinateMaker(defect_flows.ConfigurationCoordinateMaker):
     static_maker: BaseVaspMaker = field(
         default_factory=lambda: StaticMaker(input_set_generator=DEFECT_STATIC_GENERATOR)
     )
-    name: str = "config. coordinate"
+    name: str = "config coordinate"
 
 
 @dataclass
@@ -220,7 +278,7 @@ class NonRadiativeMaker(Maker):
         structure: Structure,
         charge_state1: int,
         charge_state2: int,
-    ):
+    ) -> Flow:
         """Create the job for Non-Radiative defect capture.
 
         Make a job for the calculation of the configuration coordinate diagram.
