@@ -5,60 +5,30 @@ from __future__ import annotations
 import logging
 from copy import deepcopy
 from dataclasses import dataclass, field
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 import numpy as np
-from pymatgen.core import Structure
 from pymatgen.core.periodic_table import Element
-from pymatgen.io.vasp import Outcar, Vasprun
+from pymatgen.io.vasp.sets import LobsterSet
 
-from atomate2.common.schemas.math import Vector3D
 from atomate2.vasp.sets.base import VaspInputGenerator
 
+if TYPE_CHECKING:
+    from emmet.core.math import Vector3D
+    from pymatgen.core import Structure
+    from pymatgen.io.vasp import Kpoints, Outcar, Vasprun
+
+
 logger = logging.getLogger(__name__)
 
 
-__all__ = [
-    "RelaxSetGenerator",
-    "TightRelaxSetGenerator",
-    "StaticSetGenerator",
-    "NonSCFSetGenerator",
-    "HSERelaxSetGenerator",
-    "HSEStaticSetGenerator",
-    "HSEBSSetGenerator",
-    "HSETightRelaxSetGenerator",
-    "ElectronPhononSetGenerator",
-    "MDSetGenerator",
-]
-
-
 @dataclass
 class RelaxSetGenerator(VaspInputGenerator):
     """Class to generate VASP relaxation input sets."""
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a relaxation job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a relaxation job.
 
         Returns
         -------
@@ -68,20 +38,18 @@ class RelaxSetGenerator(VaspInputGenerator):
         return {"NSW": 99, "LCHARG": False, "ISIF": 3, "IBRION": 2}
 
 
-@dataclass
-class TightRelaxSetGenerator(VaspInputGenerator):
-    """Class to generate tight VASP relaxation input sets."""
+class RelaxConstVolSetGenerator(VaspInputGenerator):
+    """Class to generate VASP constant volume relaxation input sets."""
 
     def get_incar_updates(
         self,
         structure: Structure,
         prev_incar: dict = None,
-        bandgap: float = 0,
+        bandgap: float = None,
         vasprun: Vasprun = None,
         outcar: Outcar = None,
     ) -> dict:
-        """
-        Get updates to the INCAR for a tight relaxation job.
+        """Get updates to the INCAR for a constant volume relaxation job.
 
         Parameters
         ----------
@@ -96,6 +64,22 @@ class TightRelaxSetGenerator(VaspInputGenerator):
         outcar
             An outcar from a previous calculation.
 
+        Returns
+        -------
+        dict
+            A dictionary of updates to apply.
+        """
+        return {"NSW": 99, "LCHARG": False, "ISIF": 2, "IBRION": 2}
+
+
+@dataclass
+class TightRelaxSetGenerator(VaspInputGenerator):
+    """Class to generate tight VASP relaxation input sets."""
+
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a tight relaxation job.
+
         Returns
         -------
         dict
@@ -114,6 +98,32 @@ class TightRelaxSetGenerator(VaspInputGenerator):
         }
 
 
+@dataclass
+class TightRelaxConstVolSetGenerator(VaspInputGenerator):
+    """Class to generate constant volume tight VASP relaxation input sets."""
+
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a static VASP job.
+
+        Returns
+        -------
+        dict
+            A dictionary of updates to apply.
+        """
+        return {
+            "IBRION": 2,
+            "ISIF": 2,
+            "ENCUT": 700,
+            "EDIFF": 1e-7,
+            "LAECHG": False,
+            "EDIFFG": -0.001,
+            "LREAL": False,
+            "NSW": 99,
+            "LCHARG": False,
+        }
+
+
 @dataclass
 class StaticSetGenerator(VaspInputGenerator):
     """
@@ -134,47 +144,21 @@ class StaticSetGenerator(VaspInputGenerator):
     lepsilon: bool = False
     lcalcpol: bool = False
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a static VASP job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a static VASP job.
 
         Returns
         -------
         dict
             A dictionary of updates to apply.
         """
-        updates = {
-            "NSW": 0,
-            "ISMEAR": -5,
-            "LCHARG": True,
-            "LORBIT": 11,
-            "LREAL": False,
-        }
+        updates = {"NSW": 0, "ISMEAR": -5, "LCHARG": True, "LORBIT": 11, "LREAL": False}
         if self.lepsilon:
             # LPEAD=T: numerical evaluation of overlap integral prevents LRF_COMMUTATOR
             # errors and can lead to better expt. agreement but produces slightly
             # different results
-            updates.update({"IBRION": 8, "LEPSILON": True, "LPEAD": True, "NSW": 1})
+            updates.update(IBRION=8, LEPSILON=True, LPEAD=True, NSW=1)
 
         if self.lcalcpol:
             updates["LCALCPOL"] = True
@@ -194,6 +178,9 @@ class NonSCFSetGenerator(VaspInputGenerator):
         Energy difference used to set NEDOS, based on the total energy range.
     reciprocal_density
         Density of k-mesh by reciprocal volume.
+    reciprocal_density_metal
+        Density of k-mesh by reciprocal volume for use when the system is metallic
+        and ``auto_metal_kpoints=True`` (the default).
     line_density
         Line density for line mode band structure.
     optics
@@ -208,12 +195,13 @@ class NonSCFSetGenerator(VaspInputGenerator):
     mode: str = "line"
     dedos: float = 0.02
     reciprocal_density: float = 100
+    reciprocal_density_metal: float = 400
     line_density: float = 20
     optics: bool = False
     nbands_factor: float = 1.2
     auto_ispin: bool = True
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """Ensure mode is set correctly."""
         super().__post_init__()
         self.mode = self.mode.lower()
@@ -222,32 +210,12 @@ class NonSCFSetGenerator(VaspInputGenerator):
         if self.mode not in supported_modes:
             raise ValueError(f"Supported modes are: {', '.join(supported_modes)}")
 
-    def get_kpoints_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0.0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the kpoints configuration for a non-self consistent VASP job.
+    @property
+    def kpoints_updates(self) -> dict | Kpoints:
+        """Get updates to the kpoints configuration for a non-self consistent VASP job.
 
         Note, these updates will be ignored if the user has set user_kpoint_settings.
 
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
-
         Returns
         -------
         dict
@@ -256,34 +224,17 @@ class NonSCFSetGenerator(VaspInputGenerator):
         if self.mode == "line":
             return {"line_density": self.line_density}
 
-        elif self.mode == "boltztrap":
+        if self.mode == "boltztrap":
             return {"explicit": True, "reciprocal_density": self.reciprocal_density}
 
-        return {"reciprocal_density": self.reciprocal_density}
+        return {
+            "reciprocal_density": self.reciprocal_density,
+            "reciprocal_density_metal": self.reciprocal_density_metal,
+        }
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a non-self-consistent field VASP job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a non-self-consistent field VASP job.
 
         Returns
         -------
@@ -300,29 +251,31 @@ class NonSCFSetGenerator(VaspInputGenerator):
             "KSPACING": None,
         }
 
-        if vasprun is not None:
-            # set nbands
-            nbands = int(np.ceil(vasprun.parameters["NBANDS"] * self.nbands_factor))
-            updates["NBANDS"] = nbands
+        if self.prev_vasprun is not None:
+            # set NBANDS
+            n_bands = (
+                self.prev_vasprun.parameters.get("NBANDS") or self.estimate_nbands()
+            )
+            updates["NBANDS"] = int(np.ceil(n_bands * self.nbands_factor))
 
         if self.mode == "uniform":
-            # automatic setting of nedos using the energy range and the energy step
-            nedos = _get_nedos(vasprun, self.dedos)
+            # automatic setting of NEDOS using the energy range and the energy step
+            n_edos = self._get_nedos(self.dedos)
 
             # use tetrahedron method for DOS and optics calculations
-            updates.update({"ISMEAR": -5, "ISYM": 2, "NEDOS": nedos})
+            updates.update(ISMEAR=-5, ISYM=2, NEDOS=n_edos)
 
         elif self.mode in ("line", "boltztrap"):
             # if line mode or explicit k-points (boltztrap) can't use ISMEAR=-5
             # use small sigma to avoid partial occupancies for small band gap materials
-            updates.update({"ISMEAR": 0, "SIGMA": 0.01})
+            # use a larger sigma if the material is a metal
+            sigma = 0.2 if self.bandgap == 0 else 0.01
+            updates.update({"ISMEAR": 0, "SIGMA": sigma})
 
         if self.optics:
             # LREAL not supported with LOPTICS = True; automatic NEDOS usually
             # underestimates, so set it explicitly
-            updates.update(
-                {"LOPTICS": True, "LREAL": False, "CSHIFT": 1e-5, "NEDOS": 2000}
-            )
+            updates.update(LOPTICS=True, LREAL=False, CSHIFT=1e-5, NEDOS=2000)
 
         updates["MAGMOM"] = None
 
@@ -337,32 +290,11 @@ class HSERelaxSetGenerator(VaspInputGenerator):
         By default the hybrid input sets use ALGO = Normal which is only efficient for
         VASP 6.0 and higher. See https://www.vasp.at/wiki/index.php/LFOCKACE for more
         details.
-
     """
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a VASP HSE06 relaxation job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a VASP HSE06 relaxation job.
 
         Returns
         -------
@@ -393,29 +325,9 @@ class HSETightRelaxSetGenerator(VaspInputGenerator):
         details.
     """
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a HSE tight relaxation job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for an HSE tight relaxation job.
 
         Returns
         -------
@@ -450,32 +362,11 @@ class HSEStaticSetGenerator(VaspInputGenerator):
         By default the hybrid input sets use ALGO = Normal which is only efficient for
         VASP 6.0 and higher. See https://www.vasp.at/wiki/index.php/LFOCKACE for more
         details.
-
     """
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a VASP HSE06 static job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a VASP HSE06 static job.
 
         Returns
         -------
@@ -560,7 +451,7 @@ class HSEBSSetGenerator(VaspInputGenerator):
     added_kpoints: list[Vector3D] = field(default_factory=list)
     auto_ispin: bool = True
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """Ensure mode is set correctly."""
         super().__post_init__()
 
@@ -569,32 +460,12 @@ class HSEBSSetGenerator(VaspInputGenerator):
         if self.mode not in supported_modes:
             raise ValueError(f"Supported modes are: {', '.join(supported_modes)}")
 
-    def get_kpoints_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0.0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the kpoints configuration for a VASP HSE06 band structure job.
+    @property
+    def kpoints_updates(self) -> dict | Kpoints:
+        """Get updates to the kpoints configuration for a VASP HSE06 band structure job.
 
         Note, these updates will be ignored if the user has set user_kpoint_settings.
 
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
-
         Returns
         -------
         dict
@@ -607,13 +478,13 @@ class HSEBSSetGenerator(VaspInputGenerator):
             kpoints["zero_weighted_line_density"] = self.line_density
 
         elif self.mode == "uniform_dense":
-            kpoints[
-                "zero_weighted_reciprocal_density"
-            ] = self.zero_weighted_reciprocal_density
+            kpoints["zero_weighted_reciprocal_density"] = (
+                self.zero_weighted_reciprocal_density
+            )
 
         added_kpoints = deepcopy(self.added_kpoints)
-        if vasprun is not None and self.mode == "gap":
-            bs = vasprun.get_band_structure()
+        if self.prev_vasprun is not None and self.mode == "gap":
+            bs = self.prev_vasprun.get_band_structure()
             if not bs.is_metal():
                 added_kpoints.append(bs.get_vbm()["kpoint"].frac_coords)
                 added_kpoints.append(bs.get_cbm()["kpoint"].frac_coords)
@@ -622,29 +493,9 @@ class HSEBSSetGenerator(VaspInputGenerator):
 
         return kpoints
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a VASP HSE06 band structure job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a VASP HSE06 band structure job.
 
         Returns
         -------
@@ -668,24 +519,24 @@ class HSEBSSetGenerator(VaspInputGenerator):
 
         if self.mode == "uniform" and len(self.added_kpoints) == 0:
             # automatic setting of nedos using the energy range and the energy step
-            nedos = _get_nedos(vasprun, self.dedos)
+            nedos = self._get_nedos(self.dedos)
 
             # use tetrahedron method for DOS and optics calculations
-            updates.update({"ISMEAR": -5, "NEDOS": nedos})
+            updates.update(ISMEAR=-5, NEDOS=nedos)
 
         else:
             # if line mode or explicit k-points (gap) can't use ISMEAR=-5
             # use small sigma to avoid partial occupancies for small band gap materials
-            updates.update({"ISMEAR": 0, "SIGMA": 0.01})
+            updates.update(ISMEAR=0, SIGMA=0.01)
 
-        if vasprun is not None:
+        if self.prev_vasprun is not None:
             # set nbands
-            nbands = int(np.ceil(vasprun.parameters["NBANDS"] * self.nbands_factor))
-            updates["NBANDS"] = nbands
+            n_bands = self.prev_vasprun.parameters["NBANDS"] or self.estimate_nbands()
+            updates["NBANDS"] = int(np.ceil(n_bands * self.nbands_factor))
 
         if self.optics:
             # LREAL not supported with LOPTICS
-            updates.update({"LOPTICS": True, "LREAL": False, "CSHIFT": 1e-5})
+            updates.update(LOPTICS=True, LREAL=False, CSHIFT=1e-5)
 
         updates["MAGMOM"] = None
 
@@ -725,29 +576,9 @@ class ElectronPhononSetGenerator(VaspInputGenerator):
     reciprocal_density: float = 64
     auto_ispin: bool = True
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a static VASP job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a static VASP job.
 
         Returns
         -------
@@ -774,32 +605,12 @@ class ElectronPhononSetGenerator(VaspInputGenerator):
             "PHON_LMC": True,
         }
 
-    def get_kpoints_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0.0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the kpoints configuration for a non-self consistent VASP job.
+    @property
+    def kpoints_updates(self) -> dict | Kpoints:
+        """Get updates to the kpoints configuration for a non-self consistent VASP job.
 
         Note, these updates will be ignored if the user has set user_kpoint_settings.
 
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
-
         Returns
         -------
         dict
@@ -833,63 +644,41 @@ class MDSetGenerator(VaspInputGenerator):
     start_temp: float = 300
     end_temp: float = 300
     nsteps: int = 1000
-    time_step: int = 2
+    time_step: float = 2
     auto_ispin: bool = True
 
-    def get_incar_updates(
-        self,
-        structure: Structure,
-        prev_incar: dict = None,
-        bandgap: float = 0,
-        vasprun: Vasprun = None,
-        outcar: Outcar = None,
-    ) -> dict:
-        """
-        Get updates to the INCAR for a molecular dynamics job.
-
-        Parameters
-        ----------
-        structure
-            A structure.
-        prev_incar
-            An incar from a previous calculation.
-        bandgap
-            The band gap.
-        vasprun
-            A vasprun from a previous calculation.
-        outcar
-            An outcar from a previous calculation.
+    @property
+    def incar_updates(self) -> dict:
+        """Get updates to the INCAR for a molecular dynamics job.
 
         Returns
         -------
         dict
             A dictionary of updates to apply.
         """
-        updates = self._get_ensemble_defaults(structure, self.ensemble)
+        updates = self._get_ensemble_defaults(self.structure, self.ensemble)
 
         # Based on pymatgen.io.vasp.sets.MPMDSet.
         updates.update(
-            {
-                "ENCUT": 520,
-                "TEBEG": self.start_temp,
-                "TEEND": self.end_temp,
-                "NSW": self.nsteps,
-                "POTIM": self.time_step,
-                "LCHARG": False,
-                "NELMIN": 4,
-                "MAXMIX": 20,
-                "NELM": 500,
-                "ISYM": 0,
-                "IBRION": 0,
-                "KBLOCK": 100,
-                "PREC": "Normal",
-            }
+            ENCUT=520,
+            TEBEG=self.start_temp,
+            TEEND=self.end_temp,
+            NSW=self.nsteps,
+            POTIM=self.time_step,
+            LCHARG=False,
+            NELMIN=4,
+            MAXMIX=20,
+            NELM=500,
+            ISYM=0,
+            IBRION=0,
+            KBLOCK=100,
+            PREC="Normal",
         )
 
-        if Element("H") in structure.species and updates["POTIM"] > 0.5:
+        if Element("H") in self.structure.species and updates["POTIM"] > 0.5:
             logger.warning(
                 f"Molecular dynamics time step is {updates['POTIM']}, which is "
-                "typically too large for a structure containing H. Consider set it "
+                "typically too large for a structure containing H. Consider setting it "
                 "to a value of 0.5 or smaller."
             )
 
@@ -897,9 +686,7 @@ class MDSetGenerator(VaspInputGenerator):
 
     @staticmethod
     def _get_ensemble_defaults(structure: Structure, ensemble: str) -> dict[str, Any]:
-        """
-        Get default params for the ensemble.
-        """
+        """Get default params for the ensemble."""
         defaults = {
             "nve": {"MDALGO": 1, "ISIF": 2, "ANDERSEN_PROB": 0.0},
             "nvt": {"MDALGO": 2, "ISIF": 2, "SMASS": 0},
@@ -914,19 +701,59 @@ class MDSetGenerator(VaspInputGenerator):
         }
 
         try:
-            return defaults[ensemble.lower()]  # type: ignore
-        except KeyError:
-            supported = tuple(defaults.keys())
-            raise ValueError(
-                f"Expect `ensemble` to be one of {supported}; got {ensemble}."
-            )
+            return defaults[ensemble.lower()]  # type: ignore[return-value]
+        except KeyError as err:
+            supported = tuple(defaults)
+            raise ValueError(f"Expect {ensemble=} to be one of {supported}") from err
 
 
-def _get_nedos(vasprun: Vasprun | None, dedos: float):
-    """Automatic setting of nedos using the energy range and the energy step."""
-    if vasprun is None:
-        return 2000
+@dataclass
+class LobsterTightStaticSetGenerator(LobsterSet):
+    """
+    Class to generate well-converged statics for LOBSTER analysis.
 
-    emax = max(eigs.max() for eigs in vasprun.eigenvalues.values())
-    emin = min(eigs.min() for eigs in vasprun.eigenvalues.values())
-    return int((emax - emin) / dedos)
+    Parameters
+    ----------
+    structure : Structure
+        input structure.
+    isym : int
+        ISYM entry for INCAR, only isym=-1 and isym=0 are allowed
+    ismear : int
+        ISMEAR entry for INCAR, only ismear=-5 and ismear=0 are allowed
+    reciprocal_density : int
+        Density of k-mesh by reciprocal volume
+    user_supplied_basis : dict
+        dict including basis functions for all elements in
+        structure, e.g. {"Fe": "3d 3p 4s", "O": "2s 2p"}; if not supplied, a
+        standard basis is used
+    address_basis_file : str
+        address to a file similar to "BASIS_PBE_54_standard.yaml"
+        in pymatgen.io.lobster.lobster_basis
+    user_potcar_settings :dict
+        dict including potcar settings for all elements in structure,
+        e.g. {"Fe": "Fe_pv", "O": "O"}; if not supplied, a standard basis is used.
+    **kwargs: Other kwargs supported by VaspInputSet.
+    """
+
+    reciprocal_density: int = 400
+
+    @property
+    def incar_updates(self) -> dict[str, Any]:
+        """Get updates to the INCAR for a molecular dynamics job.
+
+        Returns
+        -------
+        dict
+            A dictionary of updates to apply.
+        """
+        return super().incar_updates | {
+            "EDIFF": 1e-7,
+            "ISPIN": 1,
+            "LAECHG": False,
+            "LREAL": False,
+            "LVTOT": False,
+            "ALGO": "Normal",
+            "LCHARG": False,
+            "LWAVE": True,
+            "ISYM": 0,
+        }
